# 2022-08-23 - Polygon Root Gauge Factory V2

Deployment of the `PolygonRootGaugeFactory`, for stakeless gauges that bridge funds to their Polygon counterparts. This updated version includes caps on the relative weight (allocated emissions) for each gauge.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`PolygonRootGauge` artifact](./artifact/PolygonRootGauge.json)
- [`PolygonRootGaugeFactory` artifact](./artifact/PolygonRootGaugeFactory.json)
